function Oblique_Reg(brikdir, target_brik, input_brik,out_brik,target_Rx, ...
    input_Rx, target_angle_dir)
% This program registers axial anatomicals to oblique functionals (not vice versa)
 
%brikdir: brik directory
%target_brik: the prefix of the target brik
%input_brik: the prefix of the input brik (to be registered) 
%out_brik:  name of output brik
%target_Rx: the Rx corrdinates of the target brik (using this format [-R +L -A +P -I +S])
%input_rx: the Rx coordinate of the input brik (same format)

%target_angle_dir: 1 counterclockwise
%                 -1 clockwise
%**********AFNI BRIK ORIENTATION CONVENTION****************%
%    0 1 2 3 4 5 
%    R L P A I S
%    - + + - - +
%**********************************************************%
%    but Matlab matrix index starts with 1, so:
%    1 2 3 4 5 6 
%    R L P A I S
%    - + + - - +
%**********************************************************%

slab(1:6)=0;
dir_n=[-1 1 1 -1 -1 1];
target_brik=[brikdir '/' target_brik];
input_brik=[brikdir '/' input_brik];

stat=sprintf('!3dAttribute ORIGIN %s+orig > temp.txt',target_brik);
eval(stat);
origin=load('temp.txt');

stat=sprintf('!3dAttribute ORIENT_SPECIFIC %s+orig > temp.txt',target_brik);
eval(stat);
orient_specific=load('temp.txt');

stat=sprintf('!3dAttribute DELTA %s+orig > temp.txt',target_brik);
eval(stat);
delta=load('temp.txt');

stat=sprintf('!3dAttribute DATASET_DIMENSIONS %s+orig > temp.txt',target_brik);
eval(stat);
dimensions=load('temp.txt');

stat=sprintf('!3dAttribute DATASET_DIMENSIONS %s+orig > temp.txt',input_brik);
eval(stat);
input_dimensions=load('temp.txt');
matrix_size=input_dimensions(1:2);
nslices=input_dimensions(3);


stat=sprintf('!3dAttribute DELTA %s+orig > temp.txt',input_brik);
eval(stat);
input_delta=load('temp.txt');

FOV=abs(input_dimensions(1)*input_delta(1));
slice_thickness=abs(input_delta(3));

stat=sprintf('!3dAttribute ORIENT_SPECIFIC %s+orig > temp.txt',input_brik);
eval(stat);
orient=load('temp.txt');


!rm -f temp.txt
        
ind=orient_specific(1);
target_center(ind+1)=origin(1)+(dimensions(1)-1)*delta(1)/2;
target_center(ind+1+(-1)^ind)=origin(1)+(dimensions(1)-1)*delta(1)/2;

ind=orient_specific(2);
target_center(ind+1)=origin(2)+(dimensions(2)-1)*delta(2)/2;
target_center(ind+1+(-1)^ind)=origin(2)+(dimensions(2)-1)*delta(2)/2;

ind=orient_specific(3);
target_center(ind+1)=origin(3)+(dimensions(3)-1)*delta(3)/2;
target_center(ind+1+(-1)^ind)=origin(3)+(dimensions(3)-1)*delta(3)/2;

indt1=orient_specific(2);
indt2=orient_specific(3);
ind1=orient(2);
ind2=orient(3);

target_theta=target_angle_dir*sign((ind1-ind2)*(indt1-indt2))*atan(abs((target_Rx(indt1+1)-...
    target_Rx(indt1+1+(-1)^indt1)))/abs((target_Rx(indt2+1)-target_Rx(indt2+1+(-1)^indt2))));
input_theta=sign((ind1-ind2)*(indt1-indt2))*atan(abs((input_Rx(ind1+1)-...
    input_Rx(ind1+1+(-1)^ind1)))/abs((input_Rx(ind2+1)-input_Rx(ind2+1+(-1)^ind2))));



shift(1)=(mean([input_Rx(1) input_Rx(2)])-mean([target_Rx(1) target_Rx(2)]));
shift(2)=shift(1);
    
shift(3)=(mean([input_Rx(3) input_Rx(4)])-mean([target_Rx(3) target_Rx(4)]))*cos(target_theta)+...
    (mean([input_Rx(5) input_Rx(6)])-mean([target_Rx(5) target_Rx(6)]))*sin(target_theta);
shift(4)=shift(3);

shift(5)=(mean([input_Rx(5) input_Rx(6)])-mean([target_Rx(5) target_Rx(6)]))*cos(target_theta)-...
    (mean([input_Rx(3) input_Rx(4)])-mean([target_Rx(3) target_Rx(4)]))*sin(target_theta);
shift(6)=shift(5);

    
ind=orient(1);
input_dim(ind+1)=dir_n(ind+1)*(FOV-FOV/matrix_size(1))/2;
input_dim(ind+1+(-1)^ind)=-input_dim(ind+1);

ind=orient(2);
input_dim(ind+1)=dir_n(ind+1)*(FOV-FOV/matrix_size(2))/2;
input_dim(ind+1+(-1)^ind)=-input_dim(ind+1);

ind=orient(3);
input_dim(ind+1)=dir_n(ind+1)*(nslices-1)*slice_thickness/2;
input_dim(ind+1+(-1)^ind)=-input_dim(ind+1);


for i=1:6
    slab(i)=target_center(i)+shift(i)+input_dim(i);
end

str_x=sprintf('-xorigin_raw %s',num2str(slab(orient(1)+1)));
str_y=sprintf('-yorigin_raw %s',num2str(slab(orient(2)+1)));
str_z=sprintf('-zorigin_raw %s',num2str(slab(orient(3)+1)));

eval(sprintf('!rm -f %s_temp+orig*',input_brik));
stat=sprintf('!3dcopy %s+orig %s_temp', input_brik, input_brik);
fprintf('executed:%s\n',stat)
eval(stat);
 
stat=sprintf('!3drefit %s %s %s %s_temp+orig', str_x, str_y, str_z,input_brik);
fprintf('executed:%s\n',stat)
eval(stat);

rot_angle=(input_theta-target_theta)*180/pi;

stat=sprintf('!3drotate -verbose -prefix %s -rotate %sR 0A 0S %s_temp+orig', ...
   out_brik,num2str(rot_angle), input_brik);

fprintf('executed:%s\n',stat)
eval(stat);
eval(sprintf('!rm -f %s_temp+orig*',input_brik));
